@@ -3,6 +3,8 @@
 
 package org.torproject.onionoo.server;
 
+import org.apache.commons.lang3.StringUtils;
+
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.ArrayList;
@@ -66,7 +68,7 @@ public class ResourceServlet extends HttpServlet {
   private static Set<String> knownParameters = new HashSet<>(
       Arrays.asList(("type,running,search,lookup,fingerprint,country,as,"
           + "flag,first_seen_days,last_seen_days,contact,order,limit,"
-          + "offset,fields,family,version").split(",")));
+          + "offset,fields,family,version,host_name").split(",")));
 
   private static Set<String> illegalSearchQualifiers =
       new HashSet<>(Arrays.asList(("search,fingerprint,order,limit,"
@@ -169,6 +171,12 @@ public class ResourceServlet extends HttpServlet {
           }
           if (!parameterMap.containsKey(parameterKey)) {
             String parameterValue = parts[1];
+            if (parameterValue.startsWith("\"")
+                && parameterValue.endsWith("\"")) {
+              parameterValue = parameterValue
+                  .substring(1, parameterValue.length() - 1)
+                  .replaceAll("\\\\\"", "\"");
+            }
             parameterMap.put(parameterKey, parameterValue);
           }
         } else {
@@ -284,6 +292,15 @@ public class ResourceServlet extends HttpServlet {
       }
       rh.setVersion(versionParameter);
     }
+    if (parameterMap.containsKey("host_name")) {
+      String hostNameParameter = this.parseHostNameParameter(
+          parameterMap.get("host_name"));
+      if (null == hostNameParameter) {
+        response.sendError(HttpServletResponse.SC_BAD_REQUEST);
+        return;
+      }
+      rh.setHostName(hostNameParameter);
+    }
     if (parameterMap.containsKey("order")) {
       String[] order = this.parseOrderParameter(parameterMap.get("order"));
       if (order == null) {
@@ -388,7 +405,7 @@ public class ResourceServlet extends HttpServlet {
       + "^[0-9a-zA-Z+/]{1,27}$|" /* Base64 fingerprint. */
       + "^[0-9a-zA-Z\\.]{1,19}$|" /* Nickname or IPv4 address. */
       + ipv6AddressPatternString + "|" /* IPv6 address. */
-      + "^[a-zA-Z_]+:\\p{Graph}+$" /* Qualified search term. */);
+      + "^[a-zA-Z_]+:\"?[\\p{Graph} ]+\"?$"); /* Qualified search term. */
 
   protected static String[] parseSearchParameters(String queryString) {
     Matcher searchQueryStringMatcher = searchQueryStringPattern.matcher(
@@ -398,15 +415,39 @@ public class ResourceServlet extends HttpServlet {
       return null;
     }
     String parameter = searchQueryStringMatcher.group(1);
-    String[] searchParameters =
+    String[] spaceSeparatedParts =
         parameter.replaceAll("%20", " ").split(" ");
+    List<String> searchParameters = new ArrayList<>();
+    StringBuilder doubleQuotedSearchTerm = null;
+    for (String spaceSeparatedPart : spaceSeparatedParts) {
+      if ((StringUtils.countMatches(spaceSeparatedPart, '"')
+          - StringUtils.countMatches(spaceSeparatedPart, "\\\"")) % 2 == 0) {
+        if (null == doubleQuotedSearchTerm) {
+          searchParameters.add(spaceSeparatedPart);
+        } else {
+          doubleQuotedSearchTerm.append(' ').append(spaceSeparatedPart);
+        }
+      } else {
+        if (null == doubleQuotedSearchTerm) {
+          doubleQuotedSearchTerm = new StringBuilder(spaceSeparatedPart);
+        } else {
+          doubleQuotedSearchTerm.append(' ').append(spaceSeparatedPart);
+          searchParameters.add(doubleQuotedSearchTerm.toString());
+          doubleQuotedSearchTerm = null;
+        }
+      }
+    }
+    if (null != doubleQuotedSearchTerm) {
+      /* Opening double quote is not followed by closing double quote. */
+      return null;
+    }
     for (String searchParameter : searchParameters) {
       if (!searchParameterPattern.matcher(searchParameter).matches()) {
         /* Illegal search term. */
         return null;
       }
     }
-    return searchParameters;
+    return searchParameters.toArray(new String[0]);
   }
 
   private static Pattern fingerprintParameterPattern =
@@ -552,5 +593,16 @@ public class ResourceServlet extends HttpServlet {
     }
     return parameter;
   }
+
+  private static Pattern hostNameParameterPattern =
+      Pattern.compile("^[0-9A-Za-z_\\.\\-]+$");
+
+  private String parseHostNameParameter(String parameter) {
+    if (!hostNameParameterPattern.matcher(parameter).matches()) {
+      /* Host name contains illegal character(s). */
+      return null;
+    }
+    return parameter;
+  }
 }
 
